function tfplist = etsi_PSDmasks(tfplist);
%% ===========================================================================
%etsi_PSDmasks(tfplist) - Sets up the tfplan for ETSI VDSL PSD masks
%
% Parameter:    tfplist	        Structure describing the time and freq plan
% Returns:      tfplist		Structure describing the time and freq plan
%
% Example(s):
%   ex.tfplist = etsi_PSDmasks(ex.tfplist);    Add to existing tfplist
%   tfplan=getList(ex.tfplist,'VDSL PCabDM1');      Get this mask
%
%   ex.tfplist = etsi_PSDmasks([]);            Create a new tfplist
%   tfplan=getList(ex.tfplist,'VDSL PCabDM1');      Get this mask
%
% Reference:
%   ETSI VDSL Part 1 TS 101-270-1 V1.1.6 (1999-08)  
%% ===========================================================================

%% ===========================================================================
% Copyright (C) 1999 by Telia Research AB, Lulea, Sweden; All rights reserved. 
% Project       : FSAN xDSL simulation tool
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%
% CVS:       $Id: etsi_PSDmasks.m,v 1.8 2000/09/17 14:01:48 tono Exp $
%% ===========================================================================
% Change History
%      1999-08-30 (DaB)  Created
%      1999-09-16 (ToNo) Changed Ex.D upstream masks
%      1999-10-06 (ToNo) Rewritten for new ex struct
%      1999-10-25 (ToNo) Reorganized things into etsi,ansi,itu,fsan definitions
%      1999-11-04 (ToNo) Made it into a function
%      2000-04-05 (UvAn) Added frequency axis for the call to calcPSD
%      2000-04-11 (DaB)  added sync
%      2000-05-26 (UvAn) Added possibillities to fix the bitrate 
%% ===========================================================================

% ETSI VDSL PSD Masks from 99-08 Version 1.1.6
% -----------------------------------------

% Default values (order important!):
def_tfplan.name                  = 'N/A';
def_tfplan.PSD.downstream        = 'N/A';
def_tfplan.PSD.upstream          = 'N/A';
def_tfplan.PSD.active.upstream   = [1 30e6];
def_tfplan.PSD.active.downstream = [1 30e6];
def_tfplan.PSD.PBO.method        = 'None';	% Power back-off method (-=not applicable)
def_tfplan.PSD.PBO.param.len     = 1500;		% PBO parameter {length(m)}
def_tfplan.PSD.PBO.param.freq    = 2e6;	
def_tfplan.PSD.PBO.param.maxlen  = 1500;
def_tfplan.PSD.HAM.active        = 0;
def_tfplan.timeDivision.up       = 1; % Time used in up resp. down lin
def_tfplan.timeDivision.down     = 1;
def_tfplan.timeDivision.sync     = 1;
def_tfplan.fixBitrate.name       = 'None';  % Fixed bitrate method
def_tfplan.fixBitrate.active     = 0;       % 0=inactive, 1=active
def_tfplan.fixBitrate.param      = 'N/A';   
def_tfplan.lcname                = 'N/A';

% FTTCab models D.M1 D.M2 P.M1 P.M2
% ----------------------------------
tmp_tfplan=def_tfplan;
tmp_tfplan.name='VDSL PCabDM1';
tmp_tfplan.PSD.downstream ='calcPSD([1 -120 2 -90 552e3 -90 1104e3 -60 10000e3 -60 30000e3 -120],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream   ='calcPSD([1 -120 2 -90 552e3 -90 1104e3 -60 10000e3 -60 30000e3 -120],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan); 

tmp_tfplan=def_tfplan;
tmp_tfplan.name='VDSL PCabDM2';
tmp_tfplan.PSD.downstream ='calcPSD([1 -120 2 -90 552e3 -90 1104e3 -60 1349e3 -51.3 10000e3 -60 30000e3 -60 30000e3 -120],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream   ='calcPSD([1 -120 2 -90 552e3 -90 1104e3 -60 1349e3 -51.3 10000e3 -60 30000e3 -60 30000e3 -120],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='VDSL PCabPM1';
tmp_tfplan.PSD.downstream ='calcPSD([ 1 -120 2 -110 225e3 -110 225e3 -90 552e3 -90 1104e3 -60 10000e3 -60 30000e3 -120],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream   ='calcPSD([ 1 -120 2 -110 225e3 -110 225e3 -90 552e3 -90 1104e3 -60 10000e3 -60 30000e3 -120],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='VDSL PCabPM2';
tmp_tfplan.PSD.downstream ='calcPSD([ 1 -120 2 -110 225e3 -110 225e3 -90 552e3 -90 1104e3 -60 1349e3 -51.3 10000e3 -60 30000e3 -60 30000e3 -120],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream   ='calcPSD([ 1 -120 2 -110 225e3 -110 225e3 -90 552e3 -90 1104e3 -60 1349e3 -51.3 10000e3 -60 30000e3 -60 30000e3 -120],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);


% FTTEx models D1.M1 D1.M2 D2.M1 D2.M2 D3.M1 D3.M2 D.M1 D.M2 P.M1 P.M2
% --------------------------------------------------------------------
tmp_tfplan=def_tfplan;
tmp_tfplan.name='VDSL PExD1M1';
tmp_tfplan.PSD.downstream ='calcPSD([1 -120 2 -39.5 1104e3 -39.5 1677e3 -60 10000e3 -60 30000e3 -120],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream   ='calcPSD([1 -120 2 -39.5 138e3 -39.5 307e3 -90 552e3 -90 1104e3 -60 10000e3 -60 30000e3 -120],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='VDSL PExD1M2';
tmp_tfplan.PSD.downstream ='calcPSD([1 -120 2 -39.5 1104e3 -39.5 1394e3 -51.44 10000e3 -60 30000e3 -60 30000e3 -120],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream   ='calcPSD([1 -120 2 -39.5 138e3 -39.5 307e3 -90 552e3 -90 1104e3 -60 1349e3 -51.3 10000e3 -60 30000e3 -60 30000e3 -120],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='VDSL PExD2M1';
tmp_tfplan.PSD.downstream ='calcPSD([1 -120 2 -60 108e3 -60 138e3 -39.5 1104e3 -39.5 1677e3 -60 10000e3 -60 30000e3 -120],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream   ='calcPSD([1 -120 2 -39.5 138e3 -39.5 307e3 -90 552e3 -90 1104e3 -60 10000e3 -60 30000e3 -120],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='VDSL PExD2M2';
tmp_tfplan.PSD.downstream ='calcPSD([1 -120 2 -60 108e3 -60 138e3 -39.5 1104e3 -39.5 1394e3 -51.44 10000e3 -60 30000e3 -60 30000e3 -120],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream   ='calcPSD([1 -120 2 -39.5 138e3 -39.5 307e3 -90 552e3 -90 1104e3 -60 1349e3 -51.3 10000e3 -60 30000e3 -60 30000e3 -120],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='VDSL PExD3M1';
tmp_tfplan.PSD.downstream ='calcPSD([1 -120 2 -60 217e3 -60 276e3 -39.5 1104e3 -39.5 1677e3 -60 10000e3 -60 30000e3 -120],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream   ='calcPSD([1 -120 2 -39.5 138e3 -39.5 307e3 -90 552e3 -90 1104e3 -60 10000e3 -60 30000e3 -120],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='VDSL PExD3M2';
tmp_tfplan.PSD.downstream ='calcPSD([1 -120 2 -60 217e3 -60 276e3 -39.5 1104e3 -39.5 1394e3 -51.44 10000e3 -60 30000e3 -60 30000e3 -120],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream   ='calcPSD([1 -120 2 -39.5 138e3 -39.5 307e3 -90 552e3 -90 1104e3 -60 1349e3 -51.3 10000e3 -60 30000e3 -60 30000e3 -120],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='VDSL PExP1M1';
tmp_tfplan.PSD.downstream ='calcPSD([1 -120 2 -90 138e3 -90 138e3 -60 217e3 -60 276e3 -39.5 1104e3 -39.5 1677e3 -60 10000e3 -60 30000e3 -120],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream   ='calcPSD([1 -120 2 -90 552e3 -90 1104e3 -60 10000e3 -60 30000e3 -120],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='VDSL PExP1M2';
tmp_tfplan.PSD.downstream ='calcPSD([1 -120 2 -90 138e3 -90 138e3 -60 217e3 -60 276e3 -39.5 1104e3 -39.5 1394e3 -51.44 10000e3 -60 30000e3 -60 30000e3 -120],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream   ='calcPSD([1 -120 2 -90 552e3 -90 1104e3 -60 1349e3 -51.3 10000e3 -60 30000e3 -60 30000e3 -120],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='VDSL PExP2M1';
tmp_tfplan.PSD.downstream ='calcPSD([1 -120 2 -90 138e3 -90 138e3 -39.5 1104e3 -39.5 1677e3 -60 10000e3 -60 30000e3 -120],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream   ='calcPSD([1 -120 2 -90 552e3 -90 1104e3 -60 10000e3 -60 30000e3 -120],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='VDSL PExP2M2';
tmp_tfplan.PSD.downstream ='calcPSD([1 -120 2 -90 138e3 -90 138e3 -39.5 1104e3 -39.5 1394e3 -51.44 10000e3 -60 30000e3 -60 30000e3 -120],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream   ='calcPSD([1 -120 2 -90 552e3 -90 1104e3 -60 1349e3 -51.3 10000e3 -60 30000e3 -60 30000e3 -120],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

