function tfplist = fsan_noise(tfplist);
%% ===========================================================================
%fsan_noise(tfplist) - Sets up the tfplans for some standard alien systems
%
% Parameter:    tfplist	        Structure describing the time and freq plan
% Returns:      tfplist		Structure describing the time and freq plan
%
% Example(s):
%   ex.tfplist = fsan_noise(ex.tfplist);                Add to existing tfplist
%   tfplan=getList(ex.tfplist,''Model A (SDSL)') ;      Get this SDSL noise
%
%   ex.tfplist = fsan_noise([]);                        Create a new tfplist
%   tfplan=getList(ex.tfplist,'Model E (FTTEx VDSL)');  Get this VDSL noise
%
% Reference:
%    The FSAN xDSL simulation tool documentation
%  Mask definitions:
%    ETSI VDSL standard Part 2, Version 0.0.5 (1999-06)
%    ETSI STC TM6(98)19 rev. 3 (nov. 26, 1999)
%% ===========================================================================

%% ===========================================================================
% Copyright (C):                                        
%       1999-2000 by Telia Research AB, Lulea, Sweden;                
%       2000 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : The FSAN xDSL simulation tool
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%               : Gernot Schmid (Gernot.Schmid@arcs.ac.at)
%
% CVS:       $Id: fsan_noise.m,v 1.9 2000/09/14 10:42:01 tono Exp $
%% ===========================================================================
% Change History
%      1999-07-01 (Dab)  Created
%      1999-07-22 (ToNo) Removed the scenario definitions (done on the fly)
%      1999-07-25 (ToNo) Added ETSI Hamband def.
%      1999-08-12 (DaB)  Corrected noise model F (wrong values in ETSI doc)
%      1999-08-19 (DaB)  New structure with modemdef field
%      1999-09-30 (DaB)  Rewritten for new ex struct
%      1999-10-25 (ToNo) Reorganized things into etsi,ansi,itu,fsan definitions
%      1999-11-04 (ToNo) Made it into a function
%      2000-01-19 (GS)   Added SDSL-Noise Models 
%      2000-04-05 (UvAn) Added frequency axis for the call to calcPSD
%      2000-05-26 (UvAn) Added possibillities to fix the bitrate 
%      2000-09-14 (ToNo) Added a few of the ETSI ADSL noises
%% ===========================================================================

%% ===========================================================================
% Template, order important!

% Default values
def_tfplan.name                  = 'N/A';
def_tfplan.PSD.downstream        = 'N/A';
def_tfplan.PSD.upstream          = 'N/A';
def_tfplan.PSD.active.upstream   = [1 30e6];
def_tfplan.PSD.active.downstream = [1 30e6];
def_tfplan.PSD.PBO.method        = 'None';	% Power back-off method (-=not applicable)
def_tfplan.PSD.PBO.param.len     = 1500;		% PBO parameter {length(m)}
def_tfplan.PSD.PBO.param.freq    = 2e6;	
def_tfplan.PSD.PBO.param.maxlen  = 1500;
def_tfplan.PSD.HAM.active        = 0;
def_tfplan.timeDivision.up       = 1; % Time used in up resp. down lin
def_tfplan.timeDivision.down     = 1;
def_tfplan.fixBitrate.name       = 'None';  % Fixed bitrate method
def_tfplan.fixBitrate.active     = 0;       % 0=inactive, 1=active
def_tfplan.fixBitrate.param      = 'N/A';   
def_tfplan.lcname                = 'N/A';

%% ===========================================================================
% FSAN noise models
%-------------------

% models Alien crosstalk from a disturber shall be coupled with and NEXT
% and FEXT functions 
% Reference TD17, TD20 ETSI TM6 Villach 1999  

tmp_tfplan=def_tfplan;
tmp_tfplan.name='Model A (SDSL)';
tmp_tfplan.PSD.downstream='calcPSD([1 -18.2 50e3 -18.2 75e3 -25.4 290e3 -25.4 330e3 -26.1 1.104e6 -26.1 2.50e6 -66.2 4.53e6 -96.5 30e6 -96.5],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream='calcPSD([1 -18.2 50e3 -18.2 75e3 -25.2 275e3 -25.3 400e3 -40.5 600e3 -54.3 1e6 -71.5 2.75e6 -96.5 30e6 -96.5],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='Model B (SDSL)';
tmp_tfplan.PSD.downstream='calcPSD([1 -22.2 50e3 -22.2 77e3 -30.2 292e3 -30.3 330e3 -30.8 550e3 -30.8 600e3 -32.6 700e3 -33.6 1.104e6 -33.6 4.53e6 -101 30e6 -101],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream='calcPSD([1 -22.2 50e3 -22.2 71e3 -29.3 145e3 -29.5 175e3 -31.0 274e3 -31.0 400e3 -45.9 600e3 -59.6 1e6 -76.8 2e6 -93.5 3e6 -101 30e6 -101],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='Model C (SDSL)';
tmp_tfplan.PSD.downstream='calcPSD([1 -22.2 50e3 -22.2 74e3 -30.2 292e3 -30.3 330e3 -30.8 550e3 -30.8 600e3 -32.6 700e3 -33.6 1.104e6 -33.6 2e6 -62 15e6 -101 30e6 -101],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream='calcPSD([1	-22.2 50e3 -22.2 71e3 -29.3 145e3 -29.5 175e3 -31.0 274e3 -31.0 450e3 -48.8 900e3 -46.6 1.2e6 -48.2 1.5e6 -52.0 1.78e6 -60.3 16e6 -101 30e6 -101],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

%% ===========================================================================
% VDSL

tmp_tfplan=def_tfplan;
tmp_tfplan.name='Model A (FTTCab VDSL)';
tmp_tfplan.PSD.downstream='calcPSD([4e3 -22.2 50e3 -22.2 75e3 -30.6 100e3 -34.2 292e3 -35.3 400e3 -43.7 1.104e6 -52.6 2.5e6 -99.6 3.637e6 -111.3 30e6 -111.5],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream='calcPSD([4e3 -22.2 50e3 -22.2 75e3 -29.3 100e3 -30.8 138e3 -31 150e3 -34.2 166e3 -35.3 292e3 -35.4 400e3 -46.3 900e3 -74.5 1.104e6 -79.6 1.4e6 -82 2.5e6 -99.8 3.2e6 -103.5 4.545e6 -103.9 30e6 -103.9],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='Model B (FTTCab VDSL)';
tmp_tfplan.PSD.downstream='calcPSD([4e3 -22.2 50e3 -22.2 75e3 -30.7 100e3 -34.4 135e3 -35.3 139e3 -35.1 292e3 -35.3 400e3 -43.7 552e3 -46.7 956e3 -74.5 1.8e6 -83.3 2e6 -93.1 3.637e6 -111.3 30e6 -111.5],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream='calcPSD([4e3 -22.2 50e3 -22.1 75e3 -29.3 100e3 -30.8 138e3 -31 150e3 -34.2 166e3 -35.3 292e3 -35.4 400e3 -46.3 900e3 -74.5 1.104e6 -79.6 1.4e6 -82 2.5e6 -99.8 3.2e6 -103.5 4.545e6 -103.9 30e6 -103.9],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='Model C (FTTCab VDSL)';
tmp_tfplan.PSD.downstream='calcPSD([4e3 -22.2 50e3 -22.2 75e3 -30.6 100e3 -34.2 292e3 -35.3 400e3 -43.6 500e3 -45.4 900e3 -46.5 1.024e6 -46.9 1.4e6 -50.6 1.8e6 -60.6 16.5e6 -103.1 30e6 -109.8],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream='calcPSD([4e3 -22.2 50e3 -22.1 75e3 -29.3 100e3 -30.8 138e3 -31 150e3 -34.2 166e3 -35.3 292e3 -35.4 400e3 -46 500e3 -49.1 900e3 -47.1 1.024e6 -47.3 1.4e6 -50.7 1.8e6 -60.6 16.5e6 -101.7 30e6 -103.7],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);


tmp_tfplan=def_tfplan;
tmp_tfplan.name='Model D (FTTEx VDSL)';
tmp_tfplan.PSD.downstream='calcPSD([4e3 -18.2 50e3 -18.2 75e3 -25.1 117e3 -26.6 138e3 -25.4 290e3 -25.4 330e3 -25.8 1.104e6 -26 2.5e6 -66 4.53e6 -96 30e6 -96.4],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream='calcPSD([4e3 -18.2 50e3 -18.1 75e3 -24.2 275e3 -25.4 400e3 -40.6 600e3 -54.3 1e6 -71.6 2.75e6 -95.7 30e6 -96.4],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='Model E (FTTEx VDSL)';
tmp_tfplan.PSD.downstream='calcPSD([4e3 -22.2 50e3 -22.2 77e3 -30.9 117e3 -35 140e3 -30.2 292e3 -30.3 330e3 -30.6 550e3 -30.6 600e3 -32.5 700e3 -33.4 1.104e6 -33.5 4.53e6 -100.7 30e6 -101.1],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream='calcPSD([4e3 -22.2 50e3 -22.0 71e3 -27.8 145e3 -30 175e3 -31 274e3 -31 400e3 -46.5 600e3 -60.3 1.0e6 -77.1 1.4e6 -82.2 2.8e6 -100.3 30e6 -101.1],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='Model F (FTTEx VDSL)';
tmp_tfplan.PSD.downstream='calcPSD([4e3 -22.2 50e3 -22.2 74e3 -30.3 117e3 -35 140e3 -30.2 292e3 -30.3 330e3 -30.6 550e3 -30.6 600e3 -32.5 700e3 -33.4 1.104e6 -33.5 2.1e6 -64.6 2.45e6 -63.6 16.5e6 -99.1 30e6 -101],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream='calcPSD([0.004e6 -22.2 0.05e6 -22. 0.071e6 -27.8 0.145e6 -30. 0.175e6 -31. 0.274e6 -31. 0.45e6 -47.5 0.9e6 -45.3 1.2e6 -46.7 1.5e6 -50.4 1.78e6 -58.3 16.5e6 -99.1 30e6 -101.],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

%% ===========================================================================
% EXTENSION to SDSL-Noise Models according to 
% ETSI TM6(98)19 rev. 3 (nov. 26, 1999)

tmp_tfplan=def_tfplan;
tmp_tfplan.name='Model SDSL Noise A';
tmp_tfplan.PSD.upstream='calcPSD([1 -20 .015e6 -20 .06e6 -25.2 .276e6 -25.8 .5e6 -51.9 .57e6 -69.5 .6e6 -69.9 .65e6 -62.4 .763e6 -62.4 1e6 -71.5 2.75e6 -96.5 30e6 -96.5] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.downstream='calcPSD([1 -20 .015e6 -20 .03e6 -21.5 .067e6 -27 .125e6 -27 .138e6 -25.7 .4e6 -26.1 1.104e6 -26.1 2.5e6 -66.2 4.55e6 -96.5 30e6 -96.5],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='Model SDSL Noise B';
tmp_tfplan.PSD.upstream='calcPSD([.000001e6 -25.7 0.015e6 -25.7 .03e6 -26.8 .067e6 -31.2 .142e6 -31.2 .156e6 -32.7 .276e6 -33.2 .4e6 -46 .5e6 -57.9 .57e6 -75.7 .6e6 -76.0 .65e6 -68.3 .763e6 -68.3 1e6 -77.5 2.8e6 -103 30e6 -103],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.downstream='calcPSD([.000001e6 -25.7 .015e6 -25.7 .03e6 -27.4 .045e6 -30.3 .07e6 -36.3 .127e6 -36.3 .138e6 -32.1 .4e6 -32.5 .55e6 -32.5 .61e6 -34.8 .7e6 -35.4 1.104e6 -35.4 4.55e6 -103 30e6 -103],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='Model SDSL Noise C';
tmp_tfplan.PSD.upstream='calcPSD([.000001e6 -25.7 0.015e6 -25.7 .03e6 -26.8 .067e6 -31.2 .142e6 -31.2 .156e6 -32.7 .276e6 -33.2 .335e6 -42 .45e6 -47.9 .75e6 -45.4 1.04e6 -45.5 2.46e6 -63.6 23.44e6 -103 30e6 -103],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.downstream='calcPSD([.000001e6 -25.7 .015e6 -25.7 .03e6 -27.4 .045e6 -30.3 .07e6 -36.3 .127e6 -36.3 .138e6 -32.1 .4e6 -32.5 .55e6 -32.5 .61e6 -34.8 .7e6 -35.3 1.104e6 -35.3 1.85e6 -58.5 22.4e6 -103 30e6 -103],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);


tmp_tfplan=def_tfplan;
tmp_tfplan.name='Model SDSL Noise D';
tmp_tfplan.PSD.upstream='calcPSD([.000001e6  -300  30e6 -300],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.downstream='calcPSD([.000001e6  -300  30e6 -300],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);


%% ===========================================================================
% ETSI TM6(98)10 rev. 4 (may, 2000)

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI ADSLoP Noise A';
tmp_tfplan.PSD.upstream='calcPSD([0 -20.0 15e3 -20.0 22e3 -20.8 29e3 -20.8 61e3 -24.4 138e3 -24.5 153e3 -28.2 220e3 -28.9 315e3 -30.8 387e3 -34.6 461e3 -43.4 595e3 -62.5 755e3 -62.5 1.2e6 -75.3 2.6e6 -97.8 30e6 -97.8] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.downstream='calcPSD([0 -20.0 15e3 -20.0 31e3 -21.5 63e3 -25.6 112e3 -25.7 204e3 -26.1 298e3 -26.6 420e3 -27.3 1.104e6 -27.3 4.5e6 -97.8 30e6 -97.8 30e6 -104.1],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI ADSLoP Noise B';
tmp_tfplan.PSD.upstream='calcPSD([1 -25.6 15e3 -25.6 22e3 -26.6 29e3 -26.6 61e3 -30.3 138e3 -30.4 153e3 -33.2 220e3 -33.9 315e3 -35.5 387e3 -39.5 461e3 -48.3 605e3 -68.4 755e3 -68.4 1.2e6 -82.0 2.9e6 -104.1 30e6 -104.1] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.downstream='calcPSD([1 -25.6 15e3 -25.6 31e3 -27.0 63e3 -31.3 112e3 -31.3 204e3 -31.8 298e3 -32.5 420e3 -33.7 1.104e6 -33.7 4.5e6 -104.1 30e6 -104.1],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);
